<?php
namespace net\xmp\phpbook;
require_once './HTMLPage.php';

class LDAPConnection {

    public $handle = null;

    /**
     * Connect with LDAP directory.
     *
     * @param string $server Name of the LDAP server
     * @param string $username User name
     * @param string $password Password
     * @param boolean $secure Specifies if a connection is encrypted with TLS
     */
    function connect($server, $userName, $password, $secure=false) {
        $this->handle = ldap_connect($server);
        ldap_set_option($this->handle, LDAP_OPT_PROTOCOL_VERSION, 3);
        ldap_set_option($this->handle, LDAP_OPT_REFERRALS, 0);
        if ($secure) {
            if (!ldap_start_tls($this->handle)) {
                $this->exitWithError('TLS start failed');
            }
        }
        if (!ldap_bind($this->handle, $userName, $password)) {
            $this->exitWithError('Binding of LDAP connection failed');
        }
    }

    /**
     * Close connection to LDAP directory.
     */
    function close() {
        if ($this->handle) {
            ldap_unbind($this->handle);
            $this->handle = null;
        }
    }

    /**
     * Exit program, show error message from LDAP directory
     * @param string $txt Description of the error context
     */
    function exitWithError($txt) {
        $html = new HTMLPage('LDAP error');
        $html->addElement('p', $txt);
        $table = array(array('Number', 'Message'),
                       array(ldap_errno($this->handle), ldap_error($this->handle)));
        $html->addTable($table);
        $html->printPage();
        $this->close();
        exit;
    }
}
?>
