<?php
namespace net\xmp\phpbook;

// Exception class
class LDAPException extends Exception { }

/**
 * Authenticating a user in Active Directory
 * @param string $server Name of the server
 * @param string $username User name
 * @param string $password Password
 * @param boolean $secure Specifies if the connection is encrypted
 * @return boolean True if successful, false if not successful
 * @throws LDAPConnectionException
 */
function authenticate($server, $username, $password, $secure=true) {
    $handle = ldap_connect($server);
    if ($secure) {
        if (!ldap_start_tls($handle)) {
            throw new LDAPException('LDAP connection error');
        }
    }
    if (!ldap_bind($handle, $username, $password)) {
        $code = ldap_errno($handle);
        ldap_unbind($handle);
        if ($code != 49) {
            throw new LDAPException('LDAP connection error');
        }
        return false;
    }
    ldap_unbind($handle);
    return true;
}
