<?php
namespace net\xmp\phpbook;

// Complete listing

class LDAPEntryFormatter {

    protected $attr;
    protected $type;
    protected $url;

    function __construct($attributes, $type, $url) {
        $this->attr = $attributes;
        $this->type = $type;
        $this->url = $url;
    }

    /**
     * Returns the attributes of the LDAP entry in an array compatible with HTMLPage->addTable()
     */
    function getAttributes() {
        global $attributeConvertion;

        $table = array(array('attribute', 'value'));
        for ($i = 0; $i < $this->attr['count']; $i++) {
            $attr = $this->attr[$i];
            $link = isset($attributeConvertion[$attr]) ? $attributeConvertion[$attr] : false;
            $table[] = array($this->link($attr, 'attributeSchema'),
                             $this->getValue($attr, $link));
        }
        return $table;
    }

    /**
     * Returns the linked and converted values of an attribute
     */
    function getValue($name, $link=false) {
        if (!($cnt = $this->attr[$name]['count'])) {
            return '(empty)';
        }
        if ($cnt == 1) {
            return $this->link($this->attr[$name][0], $link);
        }
        $val = "($cnt)  ";
        for ($i = 0; $i < $cnt; $i++) {
            $val .= $this->link($this->attr[$name][$i], $link) . '; ';
        }
        return $val;
    }

    /**
     * Links a single attribute value
     */
    function link($value, $link=false) {
        $txt = htmlspecialchars($value);
        // No information -> clear text
        if ($link === false) {
            return $txt;
        }
        // Does the conversion function exist?
        elseif (function_exists('net\\xmp\\phpbook\\' . $link)) {
            $func = 'net\\xmp\\phpbook\\' . $link;
            return htmlspecialchars($func($value));
        }
        // Otherwise it is an object class
        else {
            $getdn = '';
            if (substr($link, 0, 3) === 'DN-') {
                $link = substr($link, 3);
                $getdn = '&amp;getDN=1';
            }
            return "<a  href='" . $this->url . '?name=' . rawurlencode($value)
                    . "&amp;type=$link$getdn'>$txt</a>";
        }
    }
}
?>
