<?php
// Complete listing
namespace net\xmp\phpbook;

require './HTMLPage.php';
require './LDAPConnection.php';
require './LDAPEntryFormatter.php';
require './browse_ldap_types.php';
require './AD_util.php';

$html = new HTMLPage('LDAP Browser');
$form = <<<EOF
<form action="" method="get">
Name: <input name="name" />
<select name="type">
EOF;
foreach ($objectClasses as $name => $config) {
    $form .= sprintf('<option  value="%s">%s</option>', htmlspecialchars($name),
             htmlspecialchars($config['name']));
}
$form .= <<<EOF
</select>
<input type="submit" value="search" />
</form><br />
EOF;
$html->addHTML($form);
// Check if parameters exist
if (!isset($_GET['name']) || !isset($_GET['type'])) {
    $html->printPage();
    exit;
}

// 2
// Establish connection
$ad = new LDAPConnection();
$ad->connect('doco-exch.xmp.site', 'arno@xmp.site', 'confidential');
// Filter parameters
if (!isset($objectClasses[$_GET['type']])) {
    $ad->exitWithError('Invalid entry type!');
}
$class = $objectClasses[$_GET['type']];
// Two different search types:  Search for object DN ...
if (isset($_GET['getDN'])) {
    $result = ldap_read($ad->handle, $_GET['name'], '(objectClass=*)', $class['attributes']);
}
// ... or search for baseDN with filter
else {
    $name = preg_replace($class['filterchars'], '', $_GET['name']);
    $filter = sprintf($class['filter'], $name);
    $result = ldap_search($ad->handle, $class['baseDN'], $filter, $class['attributes']);
}
if (!$result) {
    $ad->exitWithError('LDAP search failed.');
}


// 3
// The displayed information depends on the number of hits
$cnt = ldap_count_entries($ad->handle, $result);
if (!$cnt) {
    $html->addElement('p', 'No matches found.');
} elseif ($cnt == 1) {
    list($heading, $table) = listSingleEntry($ad, $result, $_GET['type']);
    $html->addElement('h2', $heading);
    $html->addTable($table, array(true, true));
} else {
    $list = listEntries($ad, $result, $_GET['type']);
    $html->addElement('h2', 'Search result');
    $html->addList($list, true);
}
// Free result buffer, close connection
ldap_free_result($result);
$ad->close();
$html->printPage();


// 4
/**
 * Returns several search hits and displays them
 */
function listEntries($ad, $result, $class) {
    $entries = ldap_get_entries($ad->handle, $result);
    if (!$entries) {
        $ad->exitWithError('Reading the LDAP search results failed.');
    }
    $list = array();
    for ($i = 0; $i < $entries['count']; $i++) {
        $list[] = '<a  href="browse_ldap.php?name=' . rawurlencode($entries[$i]['dn'])
                . '&amp;type=' . rawurlencode($class)
                . '&amp;getDN=1">' . htmlspecialchars($entries[$i]['dn']) . '</a>';
    }
    return $list;
}

// 5
/**
 * Reads a single search hit and formats it for viewing
 */
function listSingleEntry($ad, $result, $class) {
    $entry = ldap_first_entry($ad->handle, $result);
    if (!$entry) {
        $ad->exitWithError('Reading the LDAP entry failed.');
    }
    $attr = ldap_get_attributes($ad->handle, $entry);
    $ef = new LDAPEntryFormatter($attr, $class, 'browse_ldap.php');
    $table = $ef->getAttributes();
    $title = $class . ': ' . ldap_get_dn($ad->handle, $entry);
    return array($title, $table);
}
?>
